@@ -56,7 +56,7 @@ template <typename T, typename QObjectDerivedType, typename Function>
 void connectFuture(const QFuture<T> &future, QObjectDerivedType *self, const Function &fun) {
     auto watcher = std::make_shared<QFutureWatcher<T>>();
     watcher->setFuture(future);
-    QObject::connect(watcher.get(), &QFutureWatcherBase::finished, self, [self, watcher, fun, future] {
+    QObject::connect(watcher.get(), &QFutureWatcherBase::finished, self, [self, watcher, fun, future]() {
         if constexpr (std::is_same_v<void, T>) {
             if constexpr (std::is_member_function_pointer_v<Function>) {
                 (self->*fun)();
@@ -121,6 +121,8 @@ public:
     QFuture<watch::Playlist> fetchWatchPlaylist(const std::optional<QString> &videoId = std::nullopt ,
                             const std::optional<QString> &playlistId = std::nullopt);
 
+    QFuture<Lyrics> fetchLyrics(const QString &browseId);
+
     Q_SIGNAL void errorOccurred(const QString &error);
 
 protected:
