@@ -16,6 +16,7 @@
 #include "asyncdatabase.h"
 
 class FavouriteWatcher;
+class WasPlayedWatcher;
 
 struct Song {
     using ColumnTypes = std::tuple<QString, QString, QString, QString>;
@@ -37,7 +38,8 @@ class FavouritesModel : public QAbstractListModel {
     enum Roles {
         VideoId = Qt::UserRole + 1,
         Title,
-        Artist,
+        Artists,
+        ArtistsDisplayString
     };
 
 public:
@@ -73,7 +75,8 @@ public:
     enum Roles {
         VideoId = Qt::UserRole + 1,
         Title,
-        Artist,
+        Artists,
+        ArtistsDisplayString,
         Plays
     };
     Q_ENUM(Roles);
@@ -123,10 +126,13 @@ public:
     SearchHistoryModel *searches();
     Q_SIGNAL void searchesChanged();
     Q_INVOKABLE void addSearch(const QString &text);
+    Q_INVOKABLE void removeSearch(const QString &text);
 
     PlaybackHistoryModel *playbackHistory();
     Q_SIGNAL void playbackHistoryChanged();
     Q_INVOKABLE void addPlaybackHistoryItem(const QString &videoId, const QString &title, const QString &artist, const QString &album);
+    Q_INVOKABLE void removePlaybackHistoryItem(const QString &videoId);
+    Q_INVOKABLE WasPlayedWatcher *wasPlayedWatcher(const QString &videoId);
 
     PlaybackHistoryModel *mostPlayed();
 
@@ -187,3 +193,23 @@ private:
     Library *m_library;
     bool m_isFavourite = false;
 };
+
+class WasPlayedWatcher : public QObject {
+    Q_OBJECT
+    
+    Q_PROPERTY(bool wasPlayed READ wasPlayed NOTIFY wasPlayedChanged)
+    
+public:
+    WasPlayedWatcher(Library *Library, const QString &VideoId);
+    
+    bool wasPlayed() const;
+    
+    Q_SIGNAL void wasPlayedChanged();
+
+private:
+    bool m_wasPlayed = false;
+    QString m_videoId;
+    Library *m_library;
+    Q_SLOT void update(std::optional<SingleValue<bool>> result);
+    Q_SLOT void query();
+};
