@@ -39,7 +39,9 @@ QHash<int, QByteArray> PlaylistModel::roleNames() const
     return {
         {Title, "title"},
         {Artists, "artists"},
-        {VideoId, "videoId"}
+        {VideoId, "videoId"},
+        {ThumbnailUrl, "thumbnailUrl"},
+        {ArtistsDisplayString, "artistsDisplayString"}
     };
 }
 
@@ -55,6 +57,14 @@ QVariant PlaylistModel::data(const QModelIndex &index, int role) const
             return QString::fromStdString(*m_playlist.tracks[index.row()].video_id);
         }
         return {};
+    case ThumbnailUrl:
+        if (!m_playlist.tracks[index.row()].thumbnails.empty()) {
+            return QString::fromStdString(m_playlist.tracks[index.row()].thumbnails.front().url);
+        } else {
+            return {};
+        }
+    case ArtistsDisplayString:
+        return PlaylistUtils::artistsToString(m_playlist.tracks[index.row()].artists);
     }
 
     Q_UNREACHABLE();
