@@ -26,7 +26,9 @@ public:
     enum Role {
         Title,
         Artists,
-        VideoId
+        VideoId,
+        ThumbnailUrl,
+        ArtistsDisplayString
     };
 
     int rowCount(const QModelIndex &parent) const override;
