@@ -22,7 +22,7 @@ void pyPrintPretty(py::handle obj) {
 
 #define UNEXPORT __attribute__ ((visibility("hidden")))
 
-constexpr auto TESTED_YTMUSICAPI_VERSION = "0.24.0";
+constexpr auto TESTED_YTMUSICAPI_VERSION = "0.25.0";
 
 struct UNEXPORT YTMusicPrivate {
     py::scoped_interpreter guard {};
@@ -46,9 +46,9 @@ struct UNEXPORT YTMusicPrivate {
                 std::cerr << "Running with outdated and untested version of ytmusicapi." << std::endl;
                 std::cerr << "The currently tested and supported version is " << TESTED_YTMUSICAPI_VERSION << std::endl;
             } else {
-                const auto version = module.attr("version")("ytmusicapi").cast<std::string>();
+                const auto version = module.attr("__version__").cast<std::string>();
                 if (version != TESTED_YTMUSICAPI_VERSION) {
-                    std::cerr << "Running with untested version of ytmusicapi." << std::endl;
+                    std::cerr << "Running with untested version of ytmusicapi " << version << "." << std::endl;
                     std::cerr << "The currently tested and supported version is " << TESTED_YTMUSICAPI_VERSION << std::endl;
                 }
             }
@@ -144,7 +144,7 @@ album::Track extract_album_track(py::handle track) {
 
 video_info::Format extract_format(py::handle format) {
     return {
-        optional_key<int>(format, "quality"),
+        optional_key<float>(format, "quality"),
         format["url"].cast<std::string>(),
         format["vcodec"].cast<std::string>(),
         format["acodec"].cast<std::string>()
